# About Inkline
## Inkline is a modern UI/UX Library for Vue.js, designed for creating flawless content-rich responsive web applications. { .lead }

Inkline is the Vue.js UI Framework that favors not only **User Interface** and **User Experience**, but also **Developer Experience**, using a consistent and expressive API. 

In October 2019, Inkline has been selected as a finalist for the <a href="https://osawards.com/vue/" rel="nofollow">Vue.js London 2019 Open Source Awards</a>, for the Developer Experience category.

### Getting started
The only prerequisite for using Inkline is having a basic understanding of Vue.js. If you are new to Vue.js, the best way to learn is reading through the <a href="https://vuejs.org/v2/guide/" rel="nofollow" target="_blank">Official Vue.js Documentation</a>.

Finally, make sure to read through the <nuxt-link :to="{ name: 'docs-introduction-installation' }">Installation</nuxt-link> guide and discover everything Inkline has to offer.

### Core Values
When designing Inkline as a framework, there were 3 core values that the whole code base revolved around: UI, UX and DX.

<div class="docs-feature-list">

##### **UI** - User Interface 
In our view, when using Inkline as a framework you should get a great looking, reliable and flawless responsive website:

- ###### Design
    <p>Components should be designed correctly and look objectively good. The design should be minimal to offer a good base for customization.</p>
- ###### Responsiveness
    <p>Components should look great on any screen size, ranging from phones and tablets to laptops and desktops.</p>
- ###### Customization
    <p>Components should be customizable using color variants, design modifiers, and SCSS variables.</p>

##### **UX** - User Experience
A web application created with Inkline should be natural and intuitive to use. The best User Experience should be great out of the box:

- ###### Functionality
    <p>Components should be working as expected. Custom form components should have at least the same functionality as a native browser input.</p>
- ###### Visual Feedback
    <p>Components should provide hover, focus, active, disabled and readonly states whenever needed.</p>
- ###### Micro-interactions
    <p>Components should provide the right visual feedback with micro-interactions wherever possible. Animations should non-intrusive and appropriate.</p>
- ###### Accessibility
    <p>Components should be accessible and should provide the correct aria-properties for their respective states. Components should be usable when navigating with a keyboard as well.</p>

##### **DX** - Developer Experience
Last but not least, Inkline code should be a pleasure to write. This is a feature that most frameworks overlook, but it is as important as UI and UX.

- ###### Code Design
    <p>Code needs to be well written. It needs to use the best practices and provide integrations with existing tools. The code needs to be linted and follow a good style guide. The framework also needs to promote code reuse.</p>
- ###### Documentation
    <p>Great and easy to follow documentation with lots of examples. We know you love copy pasting.</p>
- ###### Consistency
    <p>Components should be natural and intuitive to use. Components should have consistent property names and class names.</p>
- ###### Performance
    <p>Webpack introduced the concept of Tree shaking. Tree shaking simply means that any module that remains unused will not be included in the final bundle that gets deployed. Inkline fully takes advantage of it.</p>
- ###### Testing
    <p>The framework needs to be well tested. Unit tests and integration tests should have a target of 100% code coverage.</p>

</div>

### FAQs
Here is a list of frequently asked questions. If you think a common question is missing from the list, please create an issue <a href="https://github.com/inkline/inkline/issues" rel="nofollow">here</a>.

1. **How is Inkline different from other UI Frameworks?**
    <p>Inkline offers an easily customizable design base for your web application. Most of the other frameworks focus on providing a predefined design style such as Material Design and are hard to extend and truly make your own.</p>
    <p>Feature-wise, some of the other frameworks offer more components, but Inkline is constantly growing and offering a great Form Validation solution.</p>
2. **What was the inspiration when creating Inkline?**
    <p>Inkline is inspired by some of the well-established UI Frameworks out there, but we took our own approach in everything. Inkline aims to be as developer-friendly as possible. The main design inspirations are Bootstrap and Bulma.</p>
3. **Does Inkline support tree-shaking?**
    <p>It does, and it does it very well! You can find how to set Inkline up for tree shaking in the <nuxt-link :to="{ name: 'docs-introduction-installation' }">Installation</nuxt-link> guide.</p>

